# Поиск неисправностей

## `Invalid --app format`

Используйте `<module>:<attribute>`, например `examples.hello_world:app`.

## Ошибки подписи маршрута

Убедитесь, что обработчики — `async def`, а первый аргумент — `ctx`.

## Проблемы со встроенной сборкой

Установите набор инструментов Rust и перестройте его с помощью `maturin build --release`.

## Ошибки сборки документов

Запустите `mkdocs build --strict` и исправьте неработающие ссылки или отсутствующие страницы.